@@ -2,8 +2,10 @@ from os.path import dirname, basename, isfile
 from .person import Person
 from .objects import Institution, Experience, Education, Contact
 from .company import Company
+from .jobs import Job
+from .job_search import JobSearch
 
-__version__ = "2.9.2"
+__version__ = "2.10.0"
 
 import glob
 modules = glob.glob(dirname(__file__)+"/*.py")
